/**
 * websocket的使用
 * 生产代码放入nginx服务时，需要配置协议升级； http 和 https 都要。
 *
 * http {
    map $http_upgrade $connection_upgrade {
       default upgrade;
       ''      close;
   }
 }
 *
 * server {
    location ~^/yqa/websocket_srv {
      proxy_pass http://localhost:8081;
      proxy_http_version 1.1;
      proxy_read_timeout 300s;
      proxy_set_header Upgrade $http_upgrade;
      proxy_set_header Connection $connection_upgrade;
    }
 }
 */

import { Notification } from 'element-ui'
import { getToken } from '@/utils/auth'

let ws_srv // websocket对象
let ws_session_id
const ws_uri = '/admin-api/websocket_srv?token='
const ws_auto = true

const wsMsg = {
  p: 'WS_MSG', // 协议类型
  msg: '' // 消息体，JSON串
}

const initWebSocket = () => {
  let ws_pre = 'ws://' + window.location.host
  const api = process.env.BASE_API
  if (api.indexOf('http') === -1) {
    ws_pre = 'ws://blinddate.havedate.cn/admin-api'
    //ws_pre = 'ws://192.168.2.226:9997'
  } else if (document.location.protocol === 'https:') {
    ws_pre = 'wss://' + window.location.host
  }
  // 判断当前浏览器是否支持WebSocket。浏览器的原生ws组件，没有心跳机制，默认是5分钟超时，具体需要参照http代理的超时配置。
  if ('WebSocket' in window) {
    ws_srv = new WebSocket(ws_pre + ws_uri + getToken())
  } else if ('MozWebSocket' in window) {
    ws_srv = new MozWebSocket(ws_pre + ws_uri + +getToken())
  } else { // 有心跳协议，可以一直保持连接。
    console.log('当前浏览器不支持WebSocket')
    // ws_uri = "/sba/ws/sockjs";
    // if(protocolStr == "https:") {
    //   ws = new SockJS("https://"+window.location.host + ws_uri);
    // } else {
    //   ws = new SockJS("http://"+window.location.host + ws_uri);
    // }
  }
  ws_srv.onopen = function() {
    Notification.success({ title: 'WS服务已连接', duration: 2500 })
  }
  // 这个事件是接受后端传过来的数据
  ws_srv.onmessage = function(event) {
    // 根据业务逻辑解析数据
    var data = JSON.parse(event.data)
    console.log('WS消息=', data)
    if (data.p === 'WS_ID') {
      ws_session_id = data.msg
    } else if (data.p === 'WS_ERR_MSG') {
      Notification.error({ title: dta.msg, duration: 2500 })
    } else {
      Notification.info({ title: 'WS消息', message: data.msg, duration: 10000 })
    }
  }
  ws_srv.onclose = function(event) {
    Notification.warning({ title: 'WS服务已关闭', duration: 1500 })
    console.log('WS关闭=', ws_session_id)
  }
  ws_srv.onerror = function(event) {
    Notification.error({ title: 'WS服务出现异常', duration: 5500 })
    console.log('WS异常=', event)
  }
}

export const wsAutoConn = () => {
  if (ws_auto) {
    closeWebsocket()
    initWebSocket()
  } else {
    console.log('ws_auto=', ws_auto)
  }
}

export const openWebsocket = () => {
  if (!ws_srv || ws_srv.readyState !== 1) { // 1: opened
    initWebSocket()
  }
}
export const closeWebsocket = () => {
  if (ws_srv && ws_srv.readyState === 1) { // opened
    ws_srv.close()
  }
}

export const sendText = (type, message) => {
  if (type !== 'info') {
    wsMsg.p = 'WS_ERR_MSG'
  }
  wsMsg.msg = message

  if (ws_srv && ws_srv.readyState === 1) { // opened
    ws_srv.send(JSON.stringify(wsMsg))
  } else {
    initWebSocket()
    ws_srv.onopen = function() {
      ws_srv.send(JSON.stringify(wsMsg))
    }
  }
}
